# TP Importer

This package is used for importing our main Titelplanung Excel file;
<br>
as this data is used in different systems this package provides adapters to use the imported data within different products
<br>
## Usage
ToDo...